@@ -64,3 +64,5 @@ class Operators:
     NOT_INTERSECTS = 'not_intersects'
     EQUALS_IGNORE_CASE = 'equals_ignore_case'
     NOT_EQUALS_IGNORE_CASE = 'not_equals_ignore_case'
+    RANGE_INCLUDES = 'range_includes'
+    RANGE_NOT_INCLUDES = 'range_not_includes'
