@@ -1,3 +1,5 @@
+import os
+
 DEFAULT_EXTERNAL_MODULES_DIR = ".external_modules"
 RESOLVED_MODULE_ENTRY_NAME = "__resolved__"
 START_LINE = '__startline__'
@@ -20,3 +22,8 @@ PARSE_ERROR_FAIL_FLAG = 'CKV_PARSE_ERROR_FAIL'
 
 PRISMA_PLATFORM = 'Prisma Cloud Code Security'
 BRIDGECREW_PLATFORM = 'Bridgecrew'
+
+MAX_IAC_FILE_SIZE = int(os.getenv('CHECKOV_MAX_IAC_FILE_SIZE', '50_000_000'))  # 50 MB is default limit
+
+
+CHECKOV_RUN_SCA_PACKAGE_SCAN_V2 = os.getenv('CHECKOV_RUN_SCA_PACKAGE_SCAN_V2', '').lower() == 'true'
\ No newline at end of file
