@@ -1,18 +1,17 @@
 from __future__ import annotations
 
-import json
 import os
-import logging
 from collections.abc import Iterable
-from typing import TYPE_CHECKING, Any, cast
+from typing import TYPE_CHECKING, Any
 
 import yaml
 
 from checkov.common.output.report import Report
 from checkov.github_actions.image_referencer.manager import GithubActionsImageReferencerManager
+from checkov.github_actions.graph_builder.local_graph import GitHubActionsLocalGraph
+from checkov.github_actions.utils import is_schema_valid, is_workflow_file
 
 from checkov.runner_filter import RunnerFilter
-from jsonschema import validate, ValidationError
 
 import checkov.common.parsers.yaml.loader as loader
 from checkov.common.images.image_referencer import Image, ImageReferencerMixin
@@ -20,21 +19,32 @@ from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.util.consts import START_LINE, END_LINE
 from checkov.common.util.type_forcers import force_dict
 from checkov.github_actions.checks.registry import registry
-from checkov.github_actions.schemas import gha_schema, gha_workflow
 from checkov.yaml_doc.runner import Runner as YamlRunner
 
 if TYPE_CHECKING:
     from checkov.common.checks.base_check_registry import BaseCheckRegistry
+    from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
+    from checkov.common.runners.graph_builder.local_graph import ObjectLocalGraph
+    from checkov.common.runners.graph_manager import ObjectGraphManager
     from networkx import DiGraph
 
-WORKFLOW_DIRECTORY = ".github/workflows/"
-
 
 class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any]]]"], YamlRunner):
     check_type = CheckType.GITHUB_ACTIONS  # noqa: CCE003  # a static attribute
 
-    def __init__(self) -> None:
-        super().__init__()
+    def __init__(
+        self,
+        db_connector: NetworkxConnector | None = None,
+        source: str = "GitHubActions",
+        graph_class: type[ObjectLocalGraph] = GitHubActionsLocalGraph,
+        graph_manager: ObjectGraphManager | None = None,
+    ) -> None:
+        super().__init__(
+            db_connector=db_connector,
+            source=source,
+            graph_class=graph_class,
+            graph_manager=graph_manager,
+        )
 
     def require_external_checks(self) -> bool:
         return False
@@ -45,23 +55,16 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
     def _parse_file(
         self, f: str, file_content: str | None = None
     ) -> tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None:
-        if self.is_workflow_file(f):
+        if is_workflow_file(f):
             entity_schema: tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None = super()._parse_file(f)
             if not file_content:
                 with open(f, 'r') as f_obj:
                     file_content = f_obj.read()
             if entity_schema and \
-                    Runner.is_schema_valid(yaml.load(file_content, Loader=loader.SafeLineLoaderGhaSchema)):  # nosec
+                    is_schema_valid(yaml.load(file_content, Loader=loader.SafeLineLoaderGhaSchema)):  # nosec
                 return entity_schema
         return None
 
-    def is_workflow_file(self, file_path: str) -> bool:
-        """
-        :return: True if the file mentioned is in a github action workflow directory and is a YAML file. Otherwise: False
-        """
-        abspath = os.path.abspath(file_path)
-        return WORKFLOW_DIRECTORY in abspath and abspath.endswith(("yml", "yaml"))
-
     def included_paths(self) -> Iterable[str]:
         return [".github"]
 
@@ -147,30 +150,9 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
 
     @staticmethod
     def resolve_step_name(job_definition: dict[str, Any], start_line: int, end_line: int) -> str:
-        for step in [step for step in job_definition.get('steps', []) or [] if step]:
+        for idx, step in enumerate([step for step in job_definition.get('steps') or [] if step]):
             if step[START_LINE] <= start_line <= end_line <= step[END_LINE]:
-                try:
-                    name = step["name"]
-                except KeyError:
-                    name = step[next(iter(step.keys()))]
-
-                return cast(str, name)
+                name = step.get('name')
+                return f"{idx + 1}[{name}]" if name else str(idx + 1)
 
         return ""
-
-    @staticmethod
-    def is_schema_valid(config: dict[str, Any] | list[dict[str, Any]]) -> bool:
-        valid = False
-        config_dict = force_dict(config)
-        try:
-            validate(config_dict, gha_workflow)
-            valid = True
-        except ValidationError:
-            try:
-                validate(config_dict, gha_schema)
-                valid = True
-            except ValidationError:
-                logging.info(f'Given entity configuration does not match the schema\n'
-                             f'config={json.dumps(config_dict, indent=4)}\n')
-
-        return valid
