@@ -15,6 +15,8 @@ class MemoryRequests(BaseK8sContainerCheck):
         self.evaluated_container_keys = ["resources/requests/memory"]
         res = conf.get("resources")
         if res:
+            if not isinstance(res, dict):
+                return CheckResult.UNKNOWN
             requests = res.get("requests")
             if requests and requests.get("memory"):
                 return CheckResult.PASSED
