@@ -9,16 +9,16 @@ from checkov.common.graph.graph_builder import Edge
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
 from checkov.common.util.consts import START_LINE, END_LINE
 from checkov.kubernetes.graph_builder.graph_components.blocks import KubernetesBlock, KubernetesBlockMetadata, KubernetesSelector
-from checkov.kubernetes.kubernetes_utils import DEFAULT_NESTED_RESOURCE_TYPE, is_invalid_k8_definition, get_resource_id, is_invalid_k8_pod_definition, K8sGraphFlags
-from checkov.kubernetes.graph_builder.graph_components.LabelSelectorEdgeBuilder import LabelSelectorEdgeBuilder
-
-
-EDGE_BUILDERS = (LabelSelectorEdgeBuilder,)
+from checkov.kubernetes.kubernetes_utils import DEFAULT_NESTED_RESOURCE_TYPE, is_invalid_k8_definition, get_resource_id, is_invalid_k8_pod_definition, K8sGraphFlags, remove_metadata_from_attribute
+from checkov.kubernetes.graph_builder.graph_components.edge_builders.LabelSelectorEdgeBuilder import LabelSelectorEdgeBuilder
+from checkov.kubernetes.graph_builder.graph_components.edge_builders.KeywordEdgeBuilder import KeywordEdgeBuilder
+from checkov.kubernetes.graph_builder.graph_components.edge_builders.NetworkPolicyEdgeBuilder import NetworkPolicyEdgeBuilder
 
 
 class KubernetesLocalGraph(LocalGraph[KubernetesBlock]):
     def __init__(self, definitions: dict[str, list[dict[str, Any]]]) -> None:
         self.definitions = definitions
+        self.edge_builders = (LabelSelectorEdgeBuilder, KeywordEdgeBuilder, NetworkPolicyEdgeBuilder)
         super().__init__()
 
     def build_graph(self, render_variables: bool, graph_flags: K8sGraphFlags | None = None) -> None:
@@ -59,6 +59,7 @@ class KubernetesLocalGraph(LocalGraph[KubernetesBlock]):
                 config = deepcopy(resource)
                 attributes = deepcopy(config)
                 attributes["resource_type"] = resource_type
+                attributes["kind"] = resource_type
                 attributes[START_LINE] = resource[START_LINE]
                 attributes[END_LINE] = resource[END_LINE]
 
@@ -86,7 +87,7 @@ class KubernetesLocalGraph(LocalGraph[KubernetesBlock]):
     def _create_edges(self) -> None:
         edges_to_create = defaultdict(list)
         for vertex_index, vertex in enumerate(self.vertices):
-            for edge_builder in EDGE_BUILDERS:
+            for edge_builder in self.edge_builders:
                 if edge_builder.should_search_for_edges(vertex):
                     current_vertex_connections = edge_builder.find_connections(vertex, self.vertices)
                     if current_vertex_connections:
@@ -104,29 +105,29 @@ class KubernetesLocalGraph(LocalGraph[KubernetesBlock]):
     def _get_k8s_block_metadata(resource: Dict[str, Any]) -> KubernetesBlockMetadata:
         name = resource.get('metadata', {}).get('name')
         spec = resource.get('spec')
+        match_labels: Dict[str, Any] | None = None
         if isinstance(spec, list):
             for spec_item in spec:
                 if spec_item.get('selector'):
-                    match_labels = spec_item.get('selector').get('matchLabels')
+                    if resource.get('kind') == "Service":
+                        match_labels = spec_item.get('selector')
+                    else:
+                        match_labels = spec_item.get('selector').get('matchLabels')
                     break
             else:
                 match_labels = None
         elif isinstance(spec, dict):
-            match_labels = spec.get('selector', {}).get('matchLabels')
-        else:
-            match_labels = None
-        KubernetesLocalGraph.remove_metadata_from_attribute(match_labels)
+            if spec.get('selector'):
+                if resource.get('kind') == "Service":
+                    match_labels = spec.get('selector')
+                else:
+                    match_labels = spec.get('selector', {}).get('matchLabels')
+        remove_metadata_from_attribute(match_labels)
         selector = KubernetesSelector(match_labels)
         labels = resource.get('metadata', {}).get('labels')
-        KubernetesLocalGraph.remove_metadata_from_attribute(labels)
+        remove_metadata_from_attribute(labels)
         return KubernetesBlockMetadata(selector, labels, name)
 
-    @staticmethod
-    def remove_metadata_from_attribute(attribute: dict[str, Any] | None) -> None:
-        if isinstance(attribute, dict):
-            attribute.pop("__startline__", None)
-            attribute.pop("__endline__", None)
-
     @staticmethod
     def _extract_nested_resources(file_conf: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         all_resources: "list[dict[str, Any]]" = []
