@@ -334,10 +334,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
 
                     try:
                         caller_context = definition_context[abs_caller_file]
-                        # HACK ALERT: module data is currently double-nested in
-                        #             definition context. If fixed, remove the
-                        #             addition of "module." at the beginning.
-                        for part in f"module.{referrer_id}".split("."):
+                        for part in referrer_id.split("."):
                             caller_context = caller_context[part]
                     except KeyError:
                         logging.debug("Unable to find caller context for: %s", abs_caller_file)
@@ -467,19 +464,23 @@ class Runner(ImageReferencerMixin, BaseRunner):
             if module_path not in mod_ref:
                 continue
 
-            for next_type in definition_context[definition]:
-                # skip if type is not a terraform resource
-                if next_type not in CHECK_BLOCK_TYPES:
+            for block_type, block_configs in definition_context[definition].items():
+                # skip if type is not a Terraform resource
+                if block_type not in CHECK_BLOCK_TYPES:
                     continue
 
-                # there may be multiple resource types - aws_bucket, etc
-                for resource_type in definition_context[definition][next_type]:
-                    # there may be multiple names for each resource type
-                    for resource_name in definition_context[definition][next_type][resource_type]:
-                        # append the skipped checks from the module to the other resources.
-                        # this could also be from a module to another module.
-                        self.context[definition][next_type][resource_type][resource_name][
-                            "skipped_checks"] += skipped_checks
+                if block_type == "module":
+                    # modules don't have a type, just a name
+                    for resource_config in block_configs.values():
+                        # append the skipped checks also from a module to another module
+                        resource_config["skipped_checks"] += skipped_checks
+                else:
+                    # there may be multiple resource types - aws_bucket, etc
+                    for resource_configs in block_configs.values():
+                        # there may be multiple names for each resource type
+                        for resource_config in resource_configs.values():
+                            # append the skipped checks from the module to the other resources.
+                            resource_config["skipped_checks"] += skipped_checks
 
     @staticmethod
     def _strip_module_referrer(file_path: str) -> Tuple[str, Optional[str]]:
